@@ -7,7 +7,7 @@ $insert class_ih
 
 $insert namespace-open
 
-    // s_ranges__: use (unsigned) characters as index to obtain
+    // s_ranges_: use (unsigned) characters as index to obtain
     //           that character's range-number.
     //           The range for EOF is defined in a constant in the
     //           class header file
@@ -15,7 +15,7 @@ $insert ranges
 
 $insert startcondinfo
     // transit to if the column's character range was sensed. Row numbers are
-    // relative to the used DFA, and d_dfaBase__ is set to the first row of
+    // relative to the used DFA, and d_dfaBase_ is set to the first row of
     // the subset to use.  The row's final two values are respectively the
     // rule that may be matched at this state, and the rule's FINAL flag. If
     // the final value equals FINAL (= 1) then, if there's no continuation,
@@ -34,10 +34,10 @@ $insert inputImplementation
     d_filename("-"),
     d_out(new std::ostream(out.rdbuf())),
 $insert interactiveInit
-    d_dfaBase__(s_dfa__)
+    d_dfaBase_(s_dfa_)
 {}
 
-void \@Base::switchStream__(std::istream &in, size_t lineNr)
+void \@Base::switchStream_(std::istream &in, size_t lineNr)
 {
     d_input.close();
     d_input = Input(new std::istream(in.rdbuf()), lineNr);
@@ -52,43 +52,15 @@ $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
           outfilename == ""     ? new std::ostream(std::cerr.rdbuf()) :
                                   new std::ofstream(outfilename)),
     d_input(new std::ifstream(infilename)),
-    d_dfaBase__(s_dfa__)
+    d_dfaBase_(s_dfa_)
 {}
 
 void \@Base::switchStreams(std::istream &in, std::ostream &out)
 {
-    switchStream__(in, 1);
+    switchStream_(in, 1);
     switchOstream(out);
 }
 
-$ignoreInteractive END      end ignored section by generator/filter.cc
-
-void \@Base::switchOstream(std::ostream &out)
-{
-    *d_out << std::flush;
-    d_out.reset(new std::ostream(out.rdbuf()));
-}
-
-$insert debugFunctions
-
-void \@Base::redo(size_t nChars)
-{
-    size_t from = nChars >= length() ? 0 : length() - nChars;
-    d_input.reRead(d_matched, from);
-    d_matched.resize(from);
-}
-
-void \@Base::switchOstream(std::string const &outfilename)
-{
-    *d_out << std::flush;
-    d_out.reset(
-            outfilename == "-"    ? new std::ostream(std::cout.rdbuf()) :
-            outfilename == ""     ? new std::ostream(std::cerr.rdbuf()) :
-                                    new std::ofstream(outfilename));
-}
-
-$ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
-
 void \@Base::switchIstream(std::string const &infilename)
 {
     d_input.close();
@@ -123,9 +95,34 @@ void \@Base::pushStream(std::string const &name)
 
 $ignoreInteractive END      end ignored section by generator/filter.cc
 
+
+void \@Base::switchOstream(std::ostream &out)
+{
+    *d_out << std::flush;
+    d_out.reset(new std::ostream(out.rdbuf()));
+}
+
+$insert debugFunctions
+
+void \@Base::redo(size_t nChars)
+{
+    size_t from = nChars >= length() ? 0 : length() - nChars;
+    d_input.reRead(d_matched, from);
+    d_matched.resize(from);
+}
+
+void \@Base::switchOstream(std::string const &outfilename)
+{
+    *d_out << std::flush;
+    d_out.reset(
+            outfilename == "-"    ? new std::ostream(std::cout.rdbuf()) :
+            outfilename == ""     ? new std::ostream(std::cerr.rdbuf()) :
+                                    new std::ofstream(outfilename));
+}
+
 void \@Base::p_pushStream(std::string const &name, std::istream *streamPtr)
 {
-    if (d_streamStack.size() == s_maxSizeofStreamStack__)
+    if (d_streamStack.size() == s_maxSizeofStreamStack_)
     {
         delete streamPtr;
         throw std::length_error("Max stream stack size exceeded");
@@ -158,23 +155,23 @@ $insert lopImplementation
 
   // See the manual's section `Run-time operations' section for an explanation
   // of this member.
-\@Base::ActionType__ \@Base::actionType__(size_t range)
+\@Base::ActionType_ \@Base::actionType_(size_t range)
 {
-    d_nextState = d_dfaBase__[d_state][range];
+    d_nextState = d_dfaBase_[d_state][range];
 
     if (d_nextState != -1)                  // transition is possible
-        return ActionType__::CONTINUE;
+        return ActionType_::CONTINUE;
 
     if (knownFinalState())                  // FINAL state reached
-        return ActionType__::MATCH;         
+        return ActionType_::MATCH;         
 
     if (d_matched.size())
-        return ActionType__::ECHO_FIRST;    // no match, echo the 1st char
+        return ActionType_::ECHO_FIRST;    // no match, echo the 1st char
 
-    return range != s_rangeOfEOF__ ? 
-                ActionType__::ECHO_CH 
+    return range != s_rangeOfEOF_ ? 
+                ActionType_::ECHO_CH 
             : 
-                ActionType__::RETURN;
+                ActionType_::RETURN;
 }
 
 void \@Base::accept(size_t nChars)          // old name: less
@@ -198,7 +195,7 @@ void \@Base::setMatchedSize(size_t length)
   // d_atBOL is updated. Finally the rule's index is returned.
   // The numbers behind the finalPtr assignments are explained in the 
   // manual's `Run-time operations' section.
-size_t \@Base::matched__(size_t ch)
+size_t \@Base::matched_(size_t ch)
 {
 $insert 4 debug "MATCH"
     d_input.reRead(ch);
@@ -241,15 +238,15 @@ $insert 4 debug "match buffer contains `" << d_matched << "'"
     return finalPtr->rule;
 }
 
-size_t \@Base::getRange__(int ch)       // using int to prevent casts
+size_t \@Base::getRange_(int ch)       // using int to prevent casts
 {
 $insert caseCheck
-    return ch == AT_EOF ? as<size_t>(s_rangeOfEOF__) : s_ranges__[ch];
+    return ch == AT_EOF ? as<size_t>(s_rangeOfEOF_) : s_ranges_[ch];
 }
 
   // At this point d_nextState contains the next state and continuation is
   // possible. The just read char. is appended to d_match
-void \@Base::continue__(int ch)
+void \@Base::continue_(int ch)
 {
 $insert 4 debug "CONTINUE, NEXT STATE: " << d_nextState
     d_state = d_nextState;
@@ -258,7 +255,7 @@ $insert 4 debug "CONTINUE, NEXT STATE: " << d_nextState
         d_matched += ch;
 }
 
-void \@Base::echoCh__(size_t ch)
+void \@Base::echoCh_(size_t ch)
 {
 $insert 4 debug "ECHO_CH" 
     *d_out << as<char>(ch);
@@ -271,38 +268,38 @@ $insert 4 debug "ECHO_CH"
    // the buffer. The first char. in the buffer is echoed to stderr. 
    // If there isn't any 1st char yet then the current char doesn't fit any
    // rules and that char is then echoed
-void \@Base::echoFirst__(size_t ch)
+void \@Base::echoFirst_(size_t ch)
 {
 $insert 4 debug "ECHO_FIRST"
     d_input.reRead(ch);
     d_input.reRead(d_matched, 1);
-    echoCh__(d_matched[0]);
+    echoCh_(d_matched[0]);
 }
 
     // Update the rules associated with the current state, do this separately
     // for BOL and std rules.
     // If a rule was set, update the rule index and the current d_matched
     // length. 
-void \@Base::updateFinals__()
+void \@Base::updateFinals_()
 {
     size_t len = d_matched.size();
 
-    int const *rf = d_dfaBase__[d_state] + s_finIdx__;
+    int const *rf = d_dfaBase_[d_state] + s_finIdx_;
 
     if (rf[0] != -1)        // update to the latest std rule
     {
-$insert 4 debug "latest std rule: " << rf[0] << ", len = " << len
+$insert 8 debug "latest std rule: " << rf[0] << ", len = " << len
         d_final.std = FinalData { as<size_t>(rf[0]), len };
     }
 
     if (rf[1] != -1)        // update to the latest bol rule
     {
-$insert 4 debug "latest BOL rule: " << rf[0] << ", len = " << len
+$insert 8 debug "latest BOL rule: " << rf[0] << ", len = " << len
         d_final.bol = FinalData { as<size_t>(rf[1]), len };
     }
 }
 
-void \@Base::reset__()
+void \@Base::reset_()
 {
     d_final = Final{ 
                     FinalData{s_unavailable, 0}, 
@@ -318,7 +315,7 @@ void \@Base::reset__()
     d_more = false;
 }
 
-int \@::executeAction__(size_t ruleIdx)
+int \@::executeAction_(size_t ruleIdx)
 try
 {
 $insert 4 debug.R  "Executing actions of rule " << ruleIdx
@@ -327,71 +324,71 @@ $insert 4 debug.R  "Executing actions of rule " << ruleIdx
 $insert 8 actions
     }
 $insert 4 debug "Rule " << ruleIdx << " did not do 'return'"
-    noReturn__();
+    noReturn_();
     return 0;
 }
-catch (Leave__ value)
+catch (Leave_ value)
 {
     return static_cast<int>(value);
 }
 
-int \@::lex__()
+int \@::lex_()
 {
-    reset__();
+    reset_();
     preCode();
 
     while (true)
     {
-        size_t ch = get__();                // fetch next char
-        size_t range = getRange__(ch);      // determine the range
+        size_t ch = get_();                // fetch next char
+        size_t range = getRange_(ch);      // determine the range
 
-        updateFinals__();                    // update the state's Final info
+        updateFinals_();                    // update the state's Final info
 
-        switch (actionType__(range))        // determine the action
+        switch (actionType_(range))        // determine the action
         {
-            case ActionType__::CONTINUE:
-                continue__(ch);
+            case ActionType_::CONTINUE:
+                continue_(ch);
             continue;
 
-            case ActionType__::MATCH:
+            case ActionType_::MATCH:
             {
-                d_token__ = executeAction__(matched__(ch));
-                if (return__())
+                d_token_ = executeAction_(matched_(ch));
+                if (return_())
                 {
                     print();
-                    postCode(PostEnum__::RETURN);
-                    return d_token__;
+                    postCode(PostEnum_::RETURN);
+                    return d_token_;
                 }
                 break;
             }
 
-            case ActionType__::ECHO_FIRST:
-                echoFirst__(ch);
+            case ActionType_::ECHO_FIRST:
+                echoFirst_(ch);
             break;
 
-            case ActionType__::ECHO_CH:
-                echoCh__(ch);
+            case ActionType_::ECHO_CH:
+                echoCh_(ch);
             break;
 
-            case ActionType__::RETURN:
+            case ActionType_::RETURN:
 $insert 16 debug  "EOF_REACHED"
                 if (!popStream())
                 {
-                     postCode(PostEnum__::END);
+                     postCode(PostEnum_::END);
                      return 0;
                 }
-                postCode(PostEnum__::POP);
+                postCode(PostEnum_::POP);
              continue;
         } // switch
 
-        postCode(PostEnum__::WIP);
+        postCode(PostEnum_::WIP);
 
-        reset__();
+        reset_();
         preCode();
     } // while
 }
 
-void \@Base::print__() const
+void \@Base::print_() const
 {
 $insert 4 print
 }
